@@ -41,13 +41,6 @@ from ..decorators import  (apply_to_mask,
                            convert_to_seconds)
 
 
-try:
-    from subprocess import DEVNULL # py3k
-except ImportError:
-    import os
-    DEVNULL = open(os.devnull, 'wb')
-
-
 
 class VideoClip(Clip):
     """Base class for video clips.
