@@ -20,7 +20,7 @@ def imdisplay(imarray, screen=None):
     pg.display.flip()
 
 
-def show(clip, t=0, with_mask=True):
+def show(clip, t=0, with_mask=True, interactive=False):
     """
     Splashes the frame of clip corresponding to time ``t``.
     
@@ -44,8 +44,24 @@ def show(clip, t=0, with_mask=True):
     if with_mask and (clip.mask != None):
         import moviepy.video.compositing.CompositeVideoClip as cvc
         clip = cvc.CompositeVideoClip([clip.set_pos((0,0))])
-    imdisplay(clip.get_frame(t))
+    img = clip.get_frame(t)
+    imdisplay(img)
 
+    if interactive:
+        result=[]
+        while True:
+            for event in pg.event.get():
+                if event.type == pg.KEYDOWN:
+                    if (event.key == pg.K_ESCAPE):
+                        print( "Keyboard interrupt" )
+                        return result
+                elif event.type == pg.MOUSEBUTTONDOWN:
+                     x,y = pg.mouse.get_pos()
+                     rgb = img[y,x]
+                     result.append({'position':(x,y), 'color':rgb})
+                     print( "position, color : ", "%s, %s"%(
+                             str((x,y)),str(rgb)))
+            time.sleep(.03)
 
 @requires_duration
 def preview(clip, fps=15, audio=True, audio_fps=22050,
@@ -105,7 +121,7 @@ def preview(clip, fps=15, audio=True, audio_fps=22050,
     result = []
     
     t0 = time.time()
-    for t in np.arange(1.0 / fps, clip.duration, 1.0 / fps):
+    for t in np.arange(1.0 / fps, clip.duration-.001, 1.0 / fps):
         
         img = clip.get_frame(t)
         
@@ -128,25 +144,4 @@ def preview(clip, fps=15, audio=True, audio_fps=22050,
                     
         t1 = time.time()
         time.sleep(max(0, t - (t1-t0)) )
-        imdisplay(img, screen)
-
-def image_preview(clip):
-    
-    clip.show()
-    result=[]
-    while True:
-        for event in pg.event.get():
-            if event.type == pg.KEYDOWN:
-                if (event.key == pg.K_ESCAPE):
-                    videoFlag.clear()
-                    print( "Keyboard interrupt" )
-                    return result
-            elif event.type == pg.MOUSEBUTTONDOWN:
-                 x,y = pg.mouse.get_pos()
-                 rgb = img[y,x]
-                 result.append({'time':t, 'position':(x,y),
-                            'color':rgb})
-                 print( "time, position, color : ", "%.03f, %s, %s"%(
-                         t,str((x,y)),str(rgb)))
-    return result
-    
+        imdisplay(img, screen)
\ No newline at end of file
